Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3126)

Unified Diff: components/autofill/core/browser/webdata/autofill_wallet_syncable_service.h

Issue 2759183003: [Merge-58] Preserve use stats of existing Wallet cards when syncing. (Closed)
Patch Set: Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/webdata/autofill_wallet_syncable_service.h
diff --git a/components/autofill/core/browser/webdata/autofill_wallet_syncable_service.h b/components/autofill/core/browser/webdata/autofill_wallet_syncable_service.h
index 03f1311640913703d7bcc4e45a34effc42f5e112..ae8bae82f66dd8aa2c73b1f6836f47172398063f 100644
--- a/components/autofill/core/browser/webdata/autofill_wallet_syncable_service.h
+++ b/components/autofill/core/browser/webdata/autofill_wallet_syncable_service.h
@@ -61,15 +61,17 @@ class AutofillWalletSyncableService
const std::string& app_locale);
private:
+ FRIEND_TEST_ALL_PREFIXES(AutofillWalletSyncableServiceTest,
+ CopyRelevantMetadataFromDisk_KeepLocalAddresses);
FRIEND_TEST_ALL_PREFIXES(
AutofillWalletSyncableServiceTest,
- CopyRelevantBillingAddressesFromDisk_KeepLocalAddresses);
- FRIEND_TEST_ALL_PREFIXES(
- AutofillWalletSyncableServiceTest,
- CopyRelevantBillingAddressesFromDisk_OverwriteOtherAddresses);
+ CopyRelevantMetadataFromDisk_OverwriteOtherAddresses);
FRIEND_TEST_ALL_PREFIXES(
AutofillWalletSyncableServiceTest,
PopulateWalletCardsAndAddresses_BillingAddressIdTransfer);
+ FRIEND_TEST_ALL_PREFIXES(AutofillWalletSyncableServiceTest,
+ CopyRelevantMetadataFromDisk_KeepUseStats);
+ FRIEND_TEST_ALL_PREFIXES(AutofillWalletSyncableServiceTest, NewWalletCard);
syncer::SyncMergeResult SetSyncData(const syncer::SyncDataList& data_list);
@@ -81,10 +83,10 @@ class AutofillWalletSyncableService
std::vector<AutofillProfile>* wallet_addresses);
// Finds the copies of the same credit card from the server and on disk and
- // overwrites the server version with the billing id saved on disk if it
- // refers to a local autofill profile. The credit card's IDs do not change
- // over time.
- static void CopyRelevantBillingAddressesFromDisk(
+ // overwrites the server version with the use stats saved on disk, and the
+ // billing id if it refers to a local autofill profile. The credit card's IDs
+ // do not change over time.
+ static void CopyRelevantMetadataFromDisk(
const AutofillTable& table,
std::vector<CreditCard>* cards_from_server);

Powered by Google App Engine
This is Rietveld 408576698